%{!?kernel_version: %{expand: %%define kernel_version %(uname -r)}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | perl -pe 's/^.*el5(.*?)$/$1/g'|sed -e 's/^$/smp/g')}}

# On RHEL 5, smp type has no tag
%if "%{type}" != "smp"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%endif

# Definitions for symvers files.
%define vmw_symvers_dir etc/vmware-tools/symvers
%define bld_symvers_file Module.symvers

Name:         vmware-tools-vmci
BuildRequires: kernel-devel redhat-rpm-config gcc make perl
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmci kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      9.0.4.0
Source1:      vmci-configModule.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

# We define this so our source packages don't contain kernel version in the release
# field but the resulting binary kmod packages they build do.  Only
# necessary on RHEL.
%{?vmw_release:Release:   %{vmw_release}.el5}
%{!?vmw_release:Release:   %{kversionreltag}.4.el5}

Source0:      vmci.tar
Source2:      vmci-vmware-PLDP-spec

%define kernel_version %(uname -r|perl -pe 's/^(.*el5).*$/$1/g')

# Make sure redhat-rpm-config is installed or the
# kernel_module_package macro will throw an error rather than a nice message
%{!?kernel_module_package: You must have the redhat-rpm-config package installed to build this package.}

%define vmware_use_symvers_file 1

# RHEL 5 defines the architecture as i386 by default, even though it's
# an i686 system with i686 kernels.  Define the _arch and _target_cpu
# defaults here so the user doesn't have to specify them on the
# command line
%ifarch i386
%define _arch i686
%define _target_cpu i686
%endif

# Lock down flavors to build to just the current flavor.
%{expand: %%define current_flavor %(uname -r|perl -pe 's/^.*\.el5(.*)$/$1/g'|perl -pe 's/^$/default/g')}
%kernel_module_package -s %{SOURCE2} %{current_flavor}

%prep
%setup -n vmci-only

# XXX: We will need to handle the .symvers file for modules
# XXX: with dependent builds.
%build
for flavor in %flavors_to_build; do
  VMCI_SYMVERS_FILE=/%{vmw_symvers_dir}/vmci-9.0.4.0-%{kernel_version}-$flavor

  make clean
  rm -rf ../$flavor ../vmci.o
  # For modules that depend on vmci, copy in the vmci symvers file
  # or die trying.
  # XXX: I can only handle dependency on one module's symvers file.
  if [ "vmci" = "vsock" -o "vmci" = "vmhgfs" ]; then
     if [ ! -e $VMCI_SYMVERS_FILE ]; then
        echo
        echo
        echo "
ERROR: Could not find $VMCI_SYMVERS_FILE.  This package relies on kernel symbols for the currently running kernel that are built from the vmware-tools-vmci source RPM package.  Please do the following:

- Rebuild the vmware-tools-vmci source RPM package.
- Install the resulting binary RPM from /usr/src/redhat/RPMS/\$ARCH/.
- Rebuild this package again."
        echo
        echo
        exit 1
     fi
     cp -f $VMCI_SYMVERS_FILE ./%{bld_symvers_file}
  fi

  # Build it!
  make
  mkdir ../$flavor
  cp ../vmci.o ../$flavor
  # Take the symvers file with us as well.
  cp ./%{bld_symvers_file} ../$flavor/%{bld_symvers_file}
done

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
for flavor in %flavors_to_build; do
  vmci_SYMVERS_FILE=%{vmw_symvers_dir}/vmci-9.0.4.0-%{kernel_version}-$flavor
  if [ "$flavor" = "default" ]; then
     flavortag=""
  else
     flavortag="$flavor"
  fi
  # Install the module and symvers file.
  install -m 644 -D ../$flavor/vmci.o $RPM_BUILD_ROOT/lib/modules/%{kernel_version}${flavortag}/extra/%{name}/vmci.ko
  install -m 644 -D ../$flavor/%{bld_symvers_file} $RPM_BUILD_ROOT/$vmci_SYMVERS_FILE
done
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmci.  The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%package common
Summary:      Contains the common files used by all the vmci kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      4.el5
Version:      8.6.14

%description common
 This package contains the common system configuration and scripts responsible for loading the vmci kernel module.  The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/chkconfig vmci off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,rhel,5 --kernel=%{kernel_version} --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,rhel,5 --dbDelAnswer VMCI_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,rhel,5 --dbAddAnswer VMCI_NAME,vmci
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-config.pl --os=linux,rhel,5 --kernel=%{kernel_version} --toConfigure=vmci
if [ -e /etc/init.d/vmci ]; then
   /sbin/chkconfig vmci on
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/chkconfig vmci off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,rhel,5 --kernel=%{kernel_version} --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,rhel,5 --dbDelAnswer VMCI_NAME
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-config.pl
/etc/rc.d/init.d/vmci

